# Miscellaneous

## Image Types

::: daft.daft.ImageMode
    options:
        filters: ["!^_"]

::: daft.daft.ImageFormat
    options:
        filters: ["!^_"]

<!-- fix: how come there's no source? -->
